package com.caimei.module.base.entity.po;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 二手商品详细信息
 *
 * @author : Charles
 * @date : 2020/7/15
 */

@Data
public class SeconHandProduct extends Product implements Serializable {
    private static final long serialVersionUID = -2976754435288893250L;


    private Integer id;
    /**
     * 是否已售 0和空未出售，1已出售
     */
    private String sold;
        /**
     * 二手商品分类，1二手仪1器，2临期产品，3其他
     */
    private String secondHandType;
        /**
         * 二手仪器分类的类型，1轻光电、2重光电、3耗材配件(仅适用于二手仪器分类多个用英文逗号分分隔)
         */
    private String instrumentType;
        /**
         * 出厂日期格式：2020年6月
         */
    private String fixedYears;
        /**
         * 产品到期日格式：2020年6月（仅适用于临期产品）
         */
    private String maturityYears;
        /**
         * 公司名称
         */
    private String companyName;
        /**
         * 是否启用详聊，1不开启，2开启(开启详聊不展示交易价)
         */
    private String detailTalkFlag;
        /**
         * 采购价/原价(该二手原始购买价格）
         */
    private Double originalPrice;

        /**
     * 采购价/原价(该二手原始购买价格）千分位串
     */
    private String originalPriceStr;
    /**
     * 交易价字符串千分位
     */
    private String price1Str;
    /**
     * 市场价价字符串千分位
     */
    private String normalPriceStr;
        /**
         * 联系人名字
         */
    private String contactName;
        /**
         * 联系方式
         */
    private String contactMobile;
        /**
         * 设备类型：1医美、2非医美
         */
    private String secondProductType;
        /**
         * 省市区（地址前部分）
         */
    private String provinceCityDistrict;
        /**
         * 详细联系地址
         */
    private String address;
        /**
         * 是否已售 0和空未出售，1已出售
         */
    private String productQuality;
        /**
         * 付款状态1:待支付、2已付款
         */
    private String payStatus;
        /**
         * 支付金额
         */
    private Double payAmount;
        /**
         * 线上支付回调返回数据存档
         */
    private String payFormData;
        /**
         * 付款方式 0后台付款、1:支付宝、2微信 、12PC-B2B网银、13PC-微信支付、14PC-支付宝、15小程序-微信支付
         */
    private String payType;
        /**
         * 线上付款时间
         */
    private Date payDate;
        /**
         * 提交时间
         */
    private Date submitDate;
        /**
         * 审核时间'
         */
    private Date reviewedDate;
        /**
         * 上架时间（审核时上架变化、自动下架后再上架变化、手动下架后上架如果不在有效期内才变化）
         */
    private Date onLineDate;
    /**
     * 上架时间字符串（年月日）
      */
    private String onLineDateStr;
    /**
     * 商品图片信息
     */
    private String image1;
	private String image2;
	private String image3;
	private String image4;
	private String image5;
    /**
     * 商品详情信息(补充信息)
     */
	private String productDetails;

    /**
     * 区Id
     */
	private Integer townId;

    /**
     * 浏览量
     */
    private Integer viewingNum;

     /**
     * //是否新上架 0非新上架，1新上架
     */
    private String newAdded;

    /**
     * 二手商品列表图片数据集合
     */
    private List<String> imageList;

    /**
     * 品牌名称
     */
    private String brandName;

    /**
     * 商品类型（二手仪器-重光电）
     */
    private String typeStr;

    /**
     * 品牌信息（品牌描述）
     */
    private String brandInfo;

    /**
     * 信息来源 1网站  2CRM  3后台
     */
    private String source;

    @Override
    public String toString() {
        return "SeconHandProduct{" +
                "sold='" + sold + '\'' +
                ", secondHandType='" + secondHandType + '\'' +
                ", instrumentType='" + instrumentType + '\'' +
                ", fixedYears='" + fixedYears + '\'' +
                ", maturityYears='" + maturityYears + '\'' +
                ", companyName='" + companyName + '\'' +
                ", detailTalkFlag='" + detailTalkFlag + '\'' +
                ", originalPrice=" + originalPrice +
                ", originalPriceStr='" + originalPriceStr + '\'' +
                ", price1Str='" + price1Str + '\'' +
                ", normalPriceStr='" + normalPriceStr + '\'' +
                ", contactName='" + contactName + '\'' +
                ", contactMobile='" + contactMobile + '\'' +
                ", secondProductType='" + secondProductType + '\'' +
                ", provinceCityDistrict='" + provinceCityDistrict + '\'' +
                ", address='" + address + '\'' +
                ", productQuality='" + productQuality + '\'' +
                ", payStatus='" + payStatus + '\'' +
                ", payAmount=" + payAmount +
                ", payFormData='" + payFormData + '\'' +
                ", payType='" + payType + '\'' +
                ", payDate=" + payDate +
                ", submitDate=" + submitDate +
                ", reviewedDate=" + reviewedDate +
                ", onLineDate=" + onLineDate +
                ", onLineDateStr='" + onLineDateStr + '\'' +
                ", image1='" + image1 + '\'' +
                ", image2='" + image2 + '\'' +
                ", image3='" + image3 + '\'' +
                ", image4='" + image4 + '\'' +
                ", image5='" + image5 + '\'' +
                ", productDetails='" + productDetails + '\'' +
                ", townId=" + townId +
                ", viewingNum=" + viewingNum +
                ", newAdded='" + newAdded + '\'' +
                ", imageList=" + imageList +
                ", brandName='" + brandName + '\'' +
                ", typeStr='" + typeStr + '\'' +
                '}';
    }
}
